@@ -3,13 +3,13 @@ import requests
 import pandas as pd
 from datetime import datetime
 
-def to_unix_epoch(date_string):
+def _to_unix_epoch(date_string):
     # Get uniq epoch time as integer
     unix_epoch = datetime.strptime(date_string, "%Y-%m-%d")
     tm = (unix_epoch - datetime(1970, 1, 1)).total_seconds()
     return int(tm)   
 
-def to_unix_w_freq(sample_len, base_time, base_type):
+def _to_unix_w_freq(sample_len, base_time, base_type):
     """
         Provide time frequency and base time, 
             returns offset time.
@@ -33,28 +33,28 @@ def to_unix_w_freq(sample_len, base_time, base_type):
         print("Unknown time unit, accepts: D, W, M, Y")
     return(new_time.timestamp())
 
-def get_unix_dates(sample_len, start_dt, end_dt):
+def _get_unix_dates(sample_len, start_dt, end_dt):
     # User provided sample length ...
 
     # ... but didn't provide anything else --> get recent sample
     if (end_dt is None) & (start_dt is None):
         today = datetime.now().strftime("%Y-%m-%d")
-        end = to_unix_epoch(today)
-        start = to_unix_w_freq(sample_len, end, 'End')
+        end = _to_unix_epoch(today)
+        start = _to_unix_w_freq(sample_len, end, 'End')
 
     # ... and provided start date --> find end date using sample length
     elif (end_dt is None) & (start_dt is not None):
-        start = to_unix_epoch(start_dt)   
-        end = to_unix_w_freq(sample_len, start, 'Start')
+        start = _to_unix_epoch(start_dt)   
+        end = _to_unix_w_freq(sample_len, start, 'Start')
 
     # ... and provided end date --> find start date using sample length
     elif (end_dt is not None) & (start_dt is None):
-        end = to_unix_epoch(end_dt)   
-        start = to_unix_w_freq(sample_len, end, 'End')
+        end = _to_unix_epoch(end_dt)   
+        start = _to_unix_w_freq(sample_len, end, 'End')
 
     # ... and provided start and end date --> ignore sample length
     elif (end_dt is not None) & (start_dt is not None):
-        end = to_unix_epoch(end_dt)
-        start = to_unix_epoch(start_dt)
+        end = _to_unix_epoch(end_dt)
+        start = _to_unix_epoch(start_dt)
 
     return(start, end)
\ No newline at end of file
